Installing and Configuring the Software

# XMLRésuméLibrary: User Guide

Getting the Software | Setting up the XML Résumé Library | Exploring the Features of XML Résumé Library

## Installing and Configuring the Software

### XML Résumé Library

The XML Résumé Library comes in a tarball (or zip archive aimed at Windows users) that includes:

- The DTD

- XSL stylesheets, for converting your XML résumé to plain text, HTML, or XSL Formatting Objects (XSL-FO). (XSL-FO can then be rendered to PDF by an FO processor like FOP.)

- Some sample résumés in XML format

- A Makefile, for generating résumé formats with a simple make command

- A few CSS stylesheets that can be used to fine-tune the appearance of the HTML version of your résumé.

The most straightforward way to make use of these resources is to recursively copy the "examples" directory to where you want to work with your résumé. For instance:

    [resume-1_5_1]$ cp -a examples ~/resume

The Makefile uses the filename `resume.xml` by default. If this is unacceptable you will need to edit the line `resume = resume` to match the filename you use, such as `resume = myresume` if your résumé is `myresume.xml`.

### Tip

You can also indicate your résumé filename on the command line when you build your résumé, e.g.:

    [resume]$ make resume=myresume

### Note

The DTD and XSL files you've downloaded to your computer aren't used by default when building your résumé. Instead, the versions on the XML Résumé Library web site are used. This ensures that you're always using the most recent version; however, it also means that builds take longer (since file have to be downloaded each time you build your résumé) and that you can't build a résumé offline.

If you'd like to use your local copy of the XSL stylesheets, edit the `xsl_base` variable in the example Makefile to point to your local XSL directory. For example:

    xsl_base = ~/resume-1_5_1/xsl

To use your local copy of the DTD, change the `DOCTYPE` declaration at the top of your resume to look like this:

    <!DOCTYPE resume PUBLIC "-//Sean Kelly//DTD Resume 1.5.1//EN"
      "~/resume-1_5_1/dtd/resume.dtd">

### Xerces, Xalan, and FOP

Each of these three packages need to be untarred and their jar files copied to your JRE's `ext/` directory. This is typically `/usr/java/jdk1.3.1_02/jre/lib/ext/`, but may vary depending on who packaged your JRE. We will simply refer to it as the `ext/` directory.

Xerces consists of the jars `xmlParserAPIs.jar`, `xercesSamples.jar`, and `xercesImpl.jar`, which are in the top directory of the Xerces zip archive.

Xalan consists of the jars `runtime.jar`, `xalanservlet.jar`, `xalansamples.jar`, `regexp.jar`, `JLex.jar`, `java_cup.jar`, `bsf.jar`, `xml-apis.jar`, `BCEL.jar`, `xsltc.jar`, `xalan.jar`, and `xercesImpl.jar` in the `bin/` directory. All of these need to be copied to the `ext/` directory.

Getting the Software | Setting up the XML Résumé Library | Exploring the Features of XML Résumé Library